@@ -1,4 +1,5 @@
 #![doc = include_str!("../README.md")]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![deny(
     future_incompatible,
     nonstandard_style,
@@ -15,11 +16,15 @@ compile_error!(
     "Both `native-tls` and `rustls` options of oxhttp can't be enabled at the same time"
 );
 
+#[cfg(feature = "client")]
 mod client;
 mod io;
 pub mod model;
+#[cfg(feature = "server")]
 mod server;
 mod utils;
 
+#[cfg(feature = "client")]
 pub use client::Client;
+#[cfg(feature = "server")]
 pub use server::Server;
